==> kbib_0.6.1.orig.tar.gz: kbib-0.6.1/kbib/kbibstart.h <==
/***************************************************************************
                          kbibstart  -  description
                             -------------------
    begin                : Sun Feb 29 2004
    copyright            : (C) 2004 by Thach Nguyen
    email                : thach@dragon.thach.com
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/
#ifndef KBIBSTART_H
#define KBIBSTART_H

#include <kdialogbase.h>
#include <kurlrequester.h>
#include <qgroupbox.h>
#include <qvgroupbox.h>
#include <qbuttongroup.h> 
#include <qradiobutton.h>

#include <qpixmap.h>
/**
@author Thach Nguyen
*/
class KBibStart : public KDialogBase
{
Q_OBJECT
public:
    KBibStart(QWidget *parent = 0, const char *name = 0);

    ~KBibStart();
 
    int getAction();
    QString getFileName();
public slots:
    //void slotNewBibTex();
    //void slotOpenBibTex();
    void slotURLChanged ();
    
    
private:
//	KPushButton *newBibFileBttn;
//	KPushButton *openBibFileBttn;
	QVGroupBox *groupBox;
	QButtonGroup *buttonGroup;
	QRadioButton *newBibTex;
	QRadioButton *openBibTex;
	KURLRequester *m_requester;
	
	QLabel *label;
	QLabel *kbibImg;
	QPixmap image;
private:
    void setLastFileName();
};

#endif

==> kbib_0.6.5.orig.tar.gz: kbib-0.6.5/kbib/kbibstart.h <==
/***************************************************************************
                          kbibstart  -  description
                             -------------------
    begin                : Sun Feb 29 2004
    copyright            : (C) 2004 by Thach Nguyen
    email                : thach.nguyen@rmit.edu.au
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/
#ifndef KBIBSTART_H
#define KBIBSTART_H

#include <kdialogbase.h>
#include <kurlrequester.h>
#include <qgroupbox.h>
#include <qvgroupbox.h>
#include <qbuttongroup.h> 
#include <qradiobutton.h>

#include <qpixmap.h>
/**
@author Thach Nguyen
*/
class KBibStart : public KDialogBase
{
Q_OBJECT
public:
    KBibStart(QWidget *parent = 0, const char *name = 0);

    ~KBibStart();
 
    int getAction();
    QString getFileName();
public slots:
    //void slotNewBibTex();
    //void slotOpenBibTex();
    void slotURLChanged ();
    
    
private:
//	KPushButton *newBibFileBttn;
//	KPushButton *openBibFileBttn;
	QVGroupBox *groupBox;
	QButtonGroup *buttonGroup;
	QRadioButton *newBibTex;
	QRadioButton *openBibTex;
	KURLRequester *m_requester;
	
	QLabel *label;
	QLabel *kbibImg;
	QPixmap image;
private:
    void setLastFileName();
};

#endif
